{ config, pkgs, ... }:

{
  # Nombre de process d'installation en parrallèle effectués par Nix
  nix.buildCores = 0;

  # The NixOS release to be compatible with for stateful data such as databases.
  system.stateVersion = "16.03";

  # On autorise les paquets non-libres
  nixpkgs.config.allowUnfree = true;

  # List packages installed in system profile. To search by name, run:
  # $ nix-env -qaP | grep wget
  environment = {
    systemPackages = with pkgs; [
      bind # utilisé pour les utilitaires comme dig
      byobu
      exfat # Pour monter les FAT avec Fuse
      git gitAndTools.gitSVN gitAndTools.tig
      gnumake
      gnupg
      gpm           # prise en charge de la souris en console
      htop
      ncdu
      nmap
      mtr
      p7zip
      parted
      pciutils
      python34Packages.glances
      pwgen
      tmux
      tree
      usbutils
      (import ./vim.nix)
      wget
      which
    ];
    shellAliases = {
      byobu = "byobu-tmux";
      tree = "tree -C";
      tree1 = "tree -d -L 1";
      tree2 = "tree -d -L 2";
      tree3 = "tree -d -L 3";
      grep = "grep --color=auto";
      vi = "vim";
    };
    etc.gitconfig.text = builtins.readFile ./gitconfig;
  };
  programs.bash = {
    enableCompletion = true;
    promptInit = builtins.readFile ./bash-prompt.sh;
    interactiveShellInit = builtins.readFile ./bash-interactive-init.sh;
  };
}
